summaryrefslogtreecommitdiffstats
path: root/interfaces/khexedit/byteseditinterface.h
diff options
context:
space:
mode:
Diffstat (limited to 'interfaces/khexedit/byteseditinterface.h')
-rw-r--r--interfaces/khexedit/byteseditinterface.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/interfaces/khexedit/byteseditinterface.h b/interfaces/khexedit/byteseditinterface.h
index dc0a9dca5..f2ec1e7bd 100644
--- a/interfaces/khexedit/byteseditinterface.h
+++ b/interfaces/khexedit/byteseditinterface.h
@@ -143,8 +143,8 @@ class BytesEditInterface
virtual bool isModified() const = 0;
public: // call for action
- /** repaint the indizes from i1 to i2 */
- virtual void repaintRange( int i1, int i2 ) = 0;
+ /** tqrepaint the indizes from i1 to i2 */
+ virtual void tqrepaintRange( int i1, int i2 ) = 0;
};
@@ -221,7 +221,7 @@ inline BytesEditInterface *bytesEditInterface( T *t )
inline TQWidget *createBytesEditWidget( TQWidget *Parent = 0, const char *Name = 0 )
{
return KParts::ComponentFactory::createInstanceFromQuery<TQWidget>
- ( TQString::fromLatin1("KHexEdit/KBytesEdit"), TQString::null, Parent, Name );
+ ( TQString::tqfromLatin1("KHexEdit/KBytesEdit"), TQString::null, Parent, Name );
}
}